@@ -1,5 +1,5 @@
 fn main() {
-    match menemen::url::Url::build_from_string("https://github.com/test?/Test?ctest".to_string()) {
+    match menemen::url::Url::build_from_string("https://behemehal.net/test?qtest=123".to_string()) {
         Ok(url) => {
             println!("{:#?}", url);
         }
