@@ -4,8 +4,9 @@ mod url_test {
 
     #[test]
     fn url_test() {
-        let url = Url::build_from_string("https://behemehal.net/test?qtest=123".to_string()).unwrap();
-        
+        let url =
+            Url::build_from_string("https://behemehal.net/test?qtest=123".to_string()).unwrap();
+
         assert_eq!(url.is_https, true);
         assert_eq!(url.host, "behemehal.net".to_string());
         assert_eq!(url.query_params.len(), 1);
@@ -15,4 +16,4 @@ mod url_test {
         assert_eq!(url.paths.len(), 1);
         assert_eq!(url.paths[0], "test".to_string());
     }
-}
\ No newline at end of file
+}
